Vumi Application Router
=============================

.. image:: https://img.shields.io/travis/smn/vumi-app-router.svg
        :target: https://travis-ci.org/smn/vumi-app-router

.. image:: https://img.shields.io/pypi/v/Vumi Application Router.svg
        :target: https://pypi.python.org/pypi/vxapprouter

.. image:: https://coveralls.io/repos/smn/vumi-app-router/badge.png?branch=develop
    :target: https://coveralls.io/r/smn/vumi-app-router?branch=develop
    :alt: Code Coverage

.. image:: https://readthedocs.org/projects/vxapprouter/badge/?version=latest
    :target: https://vxapprouter.readthedocs.org
    :alt: Vumi Application Router Docs
